# Generated by Plain 0.14.1 on 2025-01-02 03:38

import uuid

from plain import models
from plain.models import migrations


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Pageview",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True)),
                ("uuid", models.UUIDField(default=uuid.uuid4, editable=False)),
                ("title", models.CharField(blank=True, max_length=255)),
                ("url", models.URLField(db_index=True, max_length=255)),
                ("referrer", models.URLField(blank=True, max_length=255)),
                ("timestamp", models.DateTimeField(auto_now_add=True, db_index=True)),
                (
                    "user_id",
                    models.CharField(blank=True, db_index=True, max_length=255),
                ),
                (
                    "session_key",
                    models.CharField(blank=True, db_index=True, max_length=255),
                ),
            ],
            options={
                "ordering": ["-timestamp"],
            },
        ),
    ]
